@@ -100,6 +100,7 @@ class AnnotatedText(Iaswn):
         o  add_str(self, textref_str, text_str)
         o  improved_str(self, rightpadding=True)
         o  set_limits(self, limits=None, limits_str=None)
+        o  yield_sorted_textrefs(self, definition2str=False)
     """
     def __init__(self,
                  options=None):
@@ -309,7 +310,7 @@ class AnnotatedText(Iaswn):
 
             You may either use <limits> (=you have a TextRef* object) either
             <limits_str> (=a TextRef* object will be created through a call to
-            .init_from_str().
+            .init_from_str() ).
 
             If both arguments are given, only <limits> is used.
             ___________________________________________________________________
@@ -322,7 +323,7 @@ class AnnotatedText(Iaswn):
 
             o  limits_str: a source_string describing a TextRef* object
 
-            RETURNED VALUE: (bool)True if the limit has been successfully set.
+            RETURNED VALUE: (bool)True if the limits have successfully been set.
         """
         if limits:
             if limits.__class__.__name__ != \
@@ -358,3 +359,43 @@ class AnnotatedText(Iaswn):
 
         # can't set self.options["AnnotatedText:textrefs limits"]:
         return False
+
+    def yield_sorted_textrefs(self,
+                              definition2str=False):
+        """
+            AnnotatedText.yield_sorted_textrefs()
+
+            (Generator)Generate the textrefs stored in self.annotatedstrings.sorted_textrefs .
+
+            By example, if you have:
+                atext = AnnotatedText()
+                atext.add_str("MyBook.2.c", "...")
+                atext.add_str("MyBook.2.a", "...")
+                atext.add_str("MyBook.1.b", "...")
+                atext.add_str("MyBook.1.a", "...")
+
+            This method will yield:
+                * definition2str == False
+                        ((((None, 'MyBook'), ('int', 1), ('a-z(1)', 1)), None),)
+                        ((((None, 'MyBook'), ('int', 1), ('a-z(1)', 2)), None),)
+                        ((((None, 'MyBook'), ('int', 2), ('a-z(1)', 1)), None),)
+                        ((((None, 'MyBook'), ('int', 2), ('a-z(1)', 3)), None),)
+
+                * definition2str == True
+                        'MyBook.1.a'
+                        'MyBook.1.b'
+                        'MyBook.2.a'
+                        'MyBook.2.c'
+
+            ___________________________________________________________________
+
+            ARGUMENT: (bool)definition2str, True if the yielded textref are passed
+                      to .definition2str().
+
+            YIELDED VALUE: the textrefs stored in self.annotatedstrings.sorted_textrefs .
+        """
+        for textref in self.annotatedstrings.sorted_textrefs:
+            if definition2str is True:
+                yield textref.definition2str()
+            else:
+                yield textref
